#define USECOMM      // yes, we need the COMM API

//#undef NO_STRICT    // be bold!

#include <windows.h>
#include <commdlg.h>
#include <string.h>
#include <time.h>
#include <io.h>
#include <memory.h>
#include "resource.h"
//#include "tty.h" 

// constant definitions

#define GWL_NPDEMOINFO        0
#define DEMOEXTRABYTES        sizeof( LONG )

#define ABOUTDLG_USEBITMAP  1

#define ATOM_DEMOINFO       0x100

// hard coded maximum number of ports for device under Win32

#define MAXPORTS        16

// terminal size

#define MAXPORT         256
#define MAXBLOCK        256
#define MAXLENGTH       80 
#define MAXLEN_TEMPSTR  81

// ascii definitions

#define ASCII_XON       0x11
#define ASCII_XOFF      0x13
#define	HUPCL	  0x0800
#define	CLOCAL	  0x1000

// control modes
#define	CBAUD	  0x000F
#define	B110	  0x0000
#define	B300	  0x0001
#define	B600      0x0002
#define	B1200     0x0003
#define	B2400	  0x0004
#define	B4800	  0x0005
#define	B9600	  0x0006
#define	B14400	  0x0007
#define	B19200	  0x0008
#define	B38400	  0x0009
#define	B56000	  0x000A
#define	B57600	  0x000B
#define	B115200	  0x000C
#define	B128000	  0x000D
#define	B256000	  0x000E
#define	CSIZE	  0x0030
#define	CS5	  0x0000
#define	CS6	  0x0010
#define	CS7	  0x0020
#define	CS8	  0x0030
#define	CSTOPB	  0x0040
#define	CREAD	  0x0080
#define CPARITYB  0x0700
#define	PARNONO	  0x0000
#define PAREVEN   0x0100
#define	PARODD	  0x0200
#define PARMARK   0x0300
#define PARSPACE  0x0400

// Flow control setting
#define FC_DTRDSR       0x01
#define FC_RTSCTS       0x02
#define FC_XONXOFF      0x04

// data structures

typedef struct tagDEMOINFO
{
   LONG    bPort, bComport, bWatchPort ;
   BOOL    fConnected, fCount, fDynamic, fStatic ;
   BYTE    bByteSize, bFlowCtrl, bParity, bStopBits ;
   HWND    hTermWnd ;
   DWORD   dwBaudRate ;

} DEMOINFO, NEAR *NPDEMOINFO ;

// macros ( for easier readability )

#define GETHINST( x )  ((HINSTANCE) GetWindowLong( x, GWL_HINSTANCE ))
#define GETNPDEMOINFO( x ) ((NPDEMOINFO) GetWindowLong( x, GWL_NPDEMOINFO ))
#define SETNPDEMOINFO( x, y ) SetWindowLong( x, GWL_NPDEMOINFO, (LONG) y )

#define PORT( x ) (x -> bPort)
#define COMPORT( x ) ( x-> bComport )
#define WATCHPORT( x ) ( x-> bWatchPort )
#define CONNECTED( x ) (x -> fConnected)
#define BYTESIZE( x ) (x -> bByteSize)
#define FLOWCTRL( x ) (x -> bFlowCtrl)
#define PARITY( x ) (x -> bParity)
#define STOPBITS( x ) (x -> bStopBits)
#define BAUDRATE( x ) (x -> dwBaudRate)
#define COUNT( x ) (x -> fCount)
#define DYNAMIC( x ) (x -> fDynamic)
#define STATIC( x ) (x -> fStatic)

#define TERMWND( x ) (x -> hTermWnd)

#define SET_PROP( x, y, z )  SetProp( x, MAKEINTATOM( y ), z )
#define GET_PROP( x, y )     GetProp( x, MAKEINTATOM( y ) )
#define REMOVE_PROP( x, y )  RemoveProp( x, MAKEINTATOM( y ) )

// global stuff

HWND     hDEMOWnd ;
char     gszDEMOClass[] = "DEMOWndClass" ;
char     gszAppName[] = "DEMO" ;
HANDLE   ghAccel ;
DWORD    InLength[MAXPORT] = { 0L } ;
DWORD    ErrCount[MAXPORT] = {0L};
DWORD    OutLength[MAXPORT] = { 0L } ;
DWORD    InLen[MAXPORT] = { 0L } ;
DWORD    OutLen[MAXPORT] = { 0L } ; 
DWORD    In[MAXPORT] = { 0L } ;
DWORD    Out[MAXPORT] = { 0L } ;
DWORD    stime[MAXPORT] ={ 0L },dtime[MAXPORT] = { 0L } ;
DWORD    sectime[MAXPORT]= { 0L } ;
DWORD    STATUS[MAXPORT] ;
int      port ;
time_t   StartTime,EndTime[MAXPORT] ;


DWORD    BaudTable[] =
         {
            CBR_110, CBR_300, CBR_600, CBR_1200, CBR_2400,
            CBR_4800, CBR_9600, CBR_14400, CBR_19200, CBR_38400,
            CBR_56000, CBR_57600, CBR_115200, CBR_128000, CBR_256000
         } ;

DWORD    ParityTable[] =
         {
            NOPARITY, EVENPARITY, ODDPARITY, MARKPARITY, SPACEPARITY
         } ;

DWORD    StopBitsTable[] =
         {
            ONESTOPBIT, TWOSTOPBITS
         } ;

DWORD    BaudGroup[] =
         {
            CBR_110, CBR_300, CBR_600, CBR_1200, CBR_2400,
            CBR_4800, CBR_9600, CBR_14400, CBR_19200, CBR_38400,
            CBR_56000, CBR_57600, CBR_115200, CBR_128000, CBR_256000
         } ;

DWORD    ParityGroup[] =
         {
            NOPARITY, EVENPARITY, ODDPARITY, MARKPARITY, SPACEPARITY
         } ;

DWORD    StopBitsGroup[] =
         {
            ONESTOPBIT, TWOSTOPBITS
         } ;
         


DWORD    ByteSizeGroup[] =
         {
            5, 6, 7, 8
         } ;            


// function prototypes (private)

BOOL NEAR InitApplication( HANDLE ) ;
HWND NEAR InitInstance( HANDLE, int ) ;
LRESULT NEAR CreateDEMOInfo( HWND ) ;
BOOL NEAR DestroyDEMOInfo( HWND ) ;
int NEAR ReadCommBlock( HWND, LPSTR, int ) ;
BOOL NEAR WriteCommBlock( HWND );
BOOL NEAR OpenConnection( HWND ) ;
BOOL NEAR SetupConnection( HWND ) ;
BOOL NEAR CloseConnection( HWND ) ;
VOID NEAR GoModalDialogBoxParam( HINSTANCE, LPCSTR, HWND, DLGPROC, LPARAM ) ;
VOID NEAR FillComboBox( HINSTANCE, HWND, int, DWORD NEAR *, WORD, DWORD ) ;
VOID ShowForm( HWND, HDC ) ;
VOID SendCommBlock( HWND hWnd, NPDEMOINFO npDEMOInfo );
BOOL NEAR SettingsDlgInit( HWND ) ;
BOOL NEAR SettingsDlgTerm( HWND ) ;

// function prototypes (public)

DWORD FAR PASCAL CommWatchProc( LPSTR ) ;
LRESULT CALLBACK DEMOWndProc( HWND, UINT, WPARAM, LPARAM ) ;
BOOL FAR PASCAL SettingsDlgProc( HWND, UINT, WPARAM, LPARAM ) ;
LONG MyAtol(LPTSTR, LPBOOL ) ;

int APIENTRY IOP_Open(int, int);        
int APIENTRY IOP_Putc(int, LPSTR);        
int APIENTRY IOP_Getc(int, LPSTR);        
DWORD APIENTRY IOP_Write(int, LPSTR, int);       
DWORD APIENTRY IOP_Read(int, LPSTR, int);        
DWORD APIENTRY IOP_DOQ_Count(int);    
DWORD APIENTRY IOP_DIQ_Count(int);   
int APIENTRY IOP_ResetDOQ(int);    
int APIENTRY IOP_ResetDIQ(int);    
int APIENTRY IOP_SetDTR(int, int);
int APIENTRY IOP_SetRTS(int, int);       
int APIENTRY IOP_Close(int);       
int APIENTRY IOP_Ioctrl(int, int);   
int APIENTRY IOP_Flowctrl(int, int);
int APIENTRY IOP_GetIoctrl(int);
int APIENTRY IOP_GetFlowctrl(int);
int APIENTRY IOP_Status(int);      
int APIENTRY IOP_DataStatus(int);

//---------------------------------------------------------------------------
//  End of File: demo.h
//---------------------------------------------------------------------------
